aboutsummaryrefslogtreecommitdiff
path: root/examples/3-build
diff options
context:
space:
mode:
authorSteve Winslow <swinslow@gmail.com>2019-01-12 13:53:39 -0500
committerSteve Winslow <swinslow@gmail.com>2019-01-12 13:53:39 -0500
commitd14ba1b6dac5bb96fa8a3cae0a427199099b257b (patch)
treefdc7a340d82b3f44f5830866f708f5161e2c1ca6 /examples/3-build
parent26a14bdffb577e7f84597e2a175a5f3eee7c231c (diff)
downloadspdx-tools-d14ba1b6dac5bb96fa8a3cae0a427199099b257b.tar.gz
Updated imports and docs for spdx/tools-golang
Signed-off-by: Steve Winslow <swinslow@gmail.com>
Diffstat (limited to 'examples/3-build')
-rw-r--r--examples/3-build/example_build.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/3-build/example_build.go b/examples/3-build/example_build.go
index 5ddafdd..7bb2146 100644
--- a/examples/3-build/example_build.go
+++ b/examples/3-build/example_build.go
@@ -12,8 +12,8 @@ import (
"fmt"
"os"
- "github.com/swinslow/spdx-go/v0/builder"
- "github.com/swinslow/spdx-go/v0/tvsaver"
+ "github.com/spdx/tools-golang/v0/builder"
+ "github.com/spdx/tools-golang/v0/tvsaver"
)
func main() {
@@ -56,7 +56,7 @@ func main() {
// note that builder will also add the following, in addition to the
// Creator defined above:
// Creator: Tool: github.com/swinslow/spdx-go/v0/builder
// Finally, you can define one or more paths that should be ignored
// when walking through the directory. This is intended to omit files
@@ -56,7 +56,7 @@ func main() {
// note that builder will also add the following, in addition to the
// Creator defined above:
- // Creator: Tool: github.com/swinslow/spdx-go/v0/builder
+ // Creator: Tool: github.com/spdx/tools-golang/v0/builder
// Finally, you can define one or more paths that should be ignored
// when walking through the directory. This is intended to omit files